@@ -29,6 +29,7 @@ from io.output import *
 from gen.container import *
 from gen.structure import *
 from gen.layout import *
+from gen.factory import *
 
 
 class InsetText(Container):
@@ -162,4 +163,20 @@ class BoxInset(Container):
       return
     self.output.settag(TagConfig.boxes[self.type], True)
 
+class IncludeInset(Container):
+  "A child document included within another."
+
+  # the converter factory will be set in converter.py
+  converterfactory = None
+
+  def __init__(self):
+    self.parser = InsetParser()
+    self.output = ContentsOutput()
+
+  def process(self):
+    "Include the provided child document"
+    self.filename = self.parser.parameters['filename']
+    Trace.debug('Child document: ' + self.filename)
+    converter = IncludeInset.converterfactory.create(self.filename)
+    converter.convert()
 
