@@ -25,6 +25,8 @@
 from util.trace import Trace
 from math.command import *
 from post.postprocess import *
+from ref.link import *
+from ref.label import *
 
 
 class PostFormula(object):
@@ -35,14 +37,23 @@ class PostFormula(object):
 
   def postprocess(self, formula, last):
     "Postprocess any formulae"
+    self.postnumbering(formula)
     self.postcontents(formula.contents)
+    self.posttraverse(formula)
     return formula
 
+  def postnumbering(self, formula):
+    "Check if it's a numbered equation, insert number."
+    if formula.header[0] != 'numbered':
+      return
+    number = '(' + PostFormula.generator.generate(1) + ') '
+    link = Link().complete(number, type="eqnumber")
+    formula.contents.insert(0, link)
+
   def postcontents(self, contents):
     "Search for sum or integral"
     for index, bit in enumerate(contents):
       self.checklimited(contents, index)
-      self.checkroot(contents, index)
       self.checknumber(contents, index)
       if isinstance(bit, FormulaBit):
         self.postcontents(bit.contents)
@@ -58,7 +69,7 @@ class PostFormula(object):
     limits.reverse()
     if len(limits) == 0:
       return
-    tagged = TaggedText().complete(limits, 'span class="limits"')
+    tagged = TaggedBit().complete(limits, 'span class="limits"')
     contents.insert(index + 1, tagged)
 
   def findlimits(self, contents, index):
@@ -81,17 +92,6 @@ class PostFormula(object):
     bit.output.tag += ' class="bigsymbol"'
     return True
 
-  def checkroot(self, contents, index):
-    "Check for a root, insert the radical in front"
-    bit = contents[index]
-    if not hasattr(bit, 'type'):
-      return
-    if bit.type != 'sqrt':
-      return
-    radical = TaggedText().constant(u'√', 'span class="radical"')
-    root = TaggedText().complete(bit.contents, 'span class="root"')
-    bit.contents = [radical, root]
-
   def checknumber(self, contents, index):
     "Check for equation numbering"
     label = contents[index]
@@ -101,15 +101,42 @@ class PostFormula(object):
       Trace.error('Wrong contents for label ' + unicode(label))
       return
     bracket = label.contents[0]
-    labelname = bracket.literal
-    number = '(' + PostFormula.generator.generate(1) + ') '
-    Label.names[labelname] = label
-    tag = label.output.tag.replace('#', labelname)
-    label.output.settag(tag)
-    label.contents = [FormulaConstant(number)]
-    # place number at the beginning
-    del contents[index]
-    contents.insert(0, label)
+    label.anchor = bracket.literal
+    label.contents = []
+    label.output = LinkOutput()
+    # store as a Label so we know it's been seen
+    Label.names[label.anchor] = label
+
+  def posttraverse(self, formula):
+    "Traverse over the contents to alter variables and space units."
+    flat = self.flatten(formula)
+    last = None
+    for bit, contents in self.traverse(flat):
+      if bit.type == 'alpha':
+        self.italicize(bit, contents)
+      elif bit.type == 'font' and last and last.type == 'number':
+        last.contents.append(FormulaConstant(u' '))
+      last = bit
+
+  def flatten(self, bit):
+    "Return all bits as a single list of (bit, list) pairs."
+    flat = []
+    for element in bit.contents:
+      if element.type:
+        flat.append((element, bit.contents))
+      elif isinstance(element, FormulaBit):
+        flat += self.flatten(element)
+    return flat
+
+  def traverse(self, flattened):
+    "Traverse each (bit, list) pairs of the formula."
+    for element in flattened:
+      yield element
+
+  def italicize(self, bit, contents):
+    "Italicize the given bit of text."
+    index = contents.index(bit)
+    contents[index] = TaggedBit().complete([bit], 'i')
 
 Postprocessor.stages.append(PostFormula)
 
