@@ -37,7 +37,7 @@ class Link(Container):
     self.contents = list()
     self.output = LinkOutput()
 
-  def complete(self, text, anchor, url, type = None):
+  def complete(self, text, anchor = None, url = None, type = None):
     self.contents = [Constant(text)]
     if anchor:
       self.anchor = anchor
@@ -45,6 +45,8 @@ class Link(Container):
       self.url = url
     if type:
       self.type = type
+    if Options.target:
+      self.target = Options.target
     return self
 
 class ListOf(Container):
@@ -220,6 +222,8 @@ class LinkOutput(object):
       tag += ' name="' + container.anchor + '"'
     if hasattr(container, 'url'):
       tag += ' href="' + container.url + '"'
+    if hasattr(container, 'target'):
+      tag += ' target="' + container.target + '"'
     text = TaggedText().complete(container.contents, tag)
     return text.gethtml()
 
